#!/usr/bin/python

import _pythonpath
import sys

from patchmetrics.crowd import Crowd
from django.conf import settings
from launchpadlib.launchpad import Launchpad
from launchpadlib.uris import LPNET_SERVICE_ROOT
from patchmetrics.utils import (
    sync_launchpad_memberships_for,
    sync_user_memberships,
)
from patchwork.models import Person


if __name__ == '__main__':
    """Maps email addresses to Linaro personnel to track Linaro's patches

    Pulls all email addresses out of the database, checks to see if each
    email address is associated with a Linaro Login user who is a member of
    a Linaro sub-team, and if they are, add a mapping between that Person
    object and a User object (many people (email addresses) can be mapped
    onto a single User (Linaro identity)). This allows us to map patches
    by email address on to Linaro users, and thus Linaro teams.

    This script has been significantly re-written. Previously we pulled all
    users who were members of a linaro sub-team out of Launchpad and saved
    their email addresses. We lost the privilages to do this though, so now
    we look up email addresses that we know. We only know email addresses
    because someone has emailed a patch to patches@linaro.org. For this reason
    we don't automatically pick up new Linaro engineers until they have
    submitted a patch in this way, which is a change vs the old behaviour.
    """
    if settings.LPLIB_CREDENTIALS_FILE is None:
        print 'No LPLIB_CREDENTIALS_FILE defined in settings.py'
        sys.exit(1)

    input_email_addresses = [person.email for person in Person.objects.all()]

    lp = Launchpad.login_with(
        'linaro-patchwork-membership-sync',
        service_root=LPNET_SERVICE_ROOT,
        credentials_file=settings.LPLIB_CREDENTIALS_FILE,
        launchpadlib_dir=settings.LPLIB_DIR
    )

    linaro = lp.people['linaro']

    if settings.AUTH_CROWD_APPLICATION_USER:
        print "Using Crowd groups"
        whitelisted_groups = []
        if settings.CROWD_GROUPS_WHITELIST is None:
            print "No CROWD_GROUPS_WHITELIST defined, all groups will be used."
        else:
            with open(settings.CROWD_GROUPS_WHITELIST) as read_file:
                whitelisted_groups = [
                    x.strip() for x in read_file if x.strip()
                ]
        crwd = Crowd(settings.AUTH_CROWD_APPLICATION_USER,
                     settings.AUTH_CROWD_APPLICATION_PASSWORD,
                     settings.AUTH_CROWD_SERVER_REST_URI)
        sync_user_memberships(input_email_addresses, crwd, whitelisted_groups)
    else:
        print "Using Launchpad groups"
        sync_launchpad_memberships_for(input_email_addresses, linaro, lp)
