#!/usr/bin/python

"""Go through all patches under the other-unknown project and try to find a
more suitable project for them.
"""

from email.Parser import HeaderParser

import _pythonpath
from django.conf import settings
from patchwork.models import Comment, Patch, Person, Project, State
from patchwork.bin.parsemail import find_project, parse_name_and_email


def set_project_and_submitter_for_lp_branch_email(mail):
    # XXX: This is a quick hack while we don't have a separate script for
    # collecting data about Launchpad-hosted projects using the LP API.
    name = mail.get('X-Launchpad-Project')
    try:
        patch.project = Project.objects.get(linkname=name)
    except Project.DoesNotExist:
        return None

    comment = Comment.objects.get(msgid=patch.msgid).content
    submitter = None
    for line in comment.split("\n"):
        if line.startswith('committer:'):
            submitter = line.replace('committer:', '').strip()
            name, email = parse_name_and_email(submitter)
            if email is not None:
                try:
                    person = Person.objects.get(email__iexact=email)
                    user = person.user
                    if not email.endswith('@linaro.org') and user is not None:
                        # If this user is associated to a Person with an
                        # @linaro.org address, we'll use that.
                        for persona in Person.objects.filter(user=user):
                            if persona.email.endswith('@linaro.org'):
                                person = persona
                except Person.DoesNotExist:
                    person = Person(name=name, email=email)
                    person.save()
                patch.submitter = person
                patch.author = person

    # This email from Launchpad means the patch has been committed upstream,
    # so we change its state to accepted.
    patch.state = State.objects.get(name='Accepted')
    patch.save()
    # Now we overwrite date_last_state_change with the patch's creation date
    # because that makes more sense than using the date when the script ran.
    patch.date_last_state_change = patch.date
    patch.save()


project = Project.objects.get(linkname=settings.PATCHWORK_DEFAULT_PROJECT)
for patch in Patch.objects.filter(project=project):
    mail = HeaderParser().parsestr(str(patch.headers))
    new_project = find_project(mail)
    if new_project is not None:
        patch.project = new_project
        patch.save()
    elif mail.get('X-Launchpad-Project') is not None:
        set_project_and_submitter_for_lp_branch_email(mail)
    else:
        # Couldn't find a project and this is not a message from Launchpad, so
        # not much we can do about it.
        pass
