#!/usr/bin/python

import _pythonpath

from patchwork.models import Person

from patchmetrics.models import TeamMembership
from patchmetrics.gerrit import (
    GerritError,
    create_or_update_patches_from_aosp_changes,
    get_aosp_changes_from,
    )
from patchmetrics.gerrit_values import (
    GERRIT_MORE_CHANGES,
    GERRIT_SORT_KEY,
)


linaro_engineers = Person.objects.filter(
    user__id__in=TeamMembership.objects.values('member').query).distinct()

for person in linaro_engineers:
    resume_key = None
    # We are just being a little bit paranoid here.
    user_email = person.email.strip()
    while True:
        try:
            results = get_aosp_changes_from(user_email, resume_key=resume_key)
        except GerritError, e:
            if ('User %s not found' % user_email) in str(e):
                # Gerrit returns an error when you search for changes owned by
                # an email address that's not registered, but in this case we
                # just skip to the next email.
                break
            raise

        if results:
            # If we get all the changes in a single batch, the
            # GERRIT_MORE_CHANGES key will not be in the JSON output, so we
            # set it to False.
            more_changes = results[-1].get(GERRIT_MORE_CHANGES) or False
            created_or_updated_patches = (
                create_or_update_patches_from_aosp_changes(results, person))

            # If there are less created/updated changes than the number of
            # changes returned by Gerrit we know we can stop as they're sorted
            # most recently updated first.
            if len(results) != len(created_or_updated_patches) or \
            (not more_changes):
                break

            resume_key = results[-1].get(GERRIT_SORT_KEY)
        else:
            break
