from datetime import datetime

from patchwork.tests.factory import ObjectFactory
from patchwork.models import Person, State
from patchmetrics.models import GerritChange, Team


class PatchMetricsObjectFactory(ObjectFactory):

    def makeTeam(self, name=None, display_name=None):
        if name is None:
            name = self.getUniqueString()
        if display_name is None:
            display_name = self.getUniqueString()
        team = Team(name=name, display_name=display_name)
        team.save()
        return team

    def makeTeamMembership(self, team=None, member=None):
        if member is None:
            member = self.makeUser()
        if team is None:
            team = self.makeTeam()
        membership = team.add_member(member)
        membership.save()
        return membership

    def makeLinaroPatch(self, project=None, date=None, content=None,
                        state_name=None):
        email = "%s@linaro.org" % self.getUniqueString('email')
        author = Person(email=email, name=self.getUniqueString())
        author.save()
        patch = self.makePatch(project=project, date=date, content=content,
                               author=author, submitter=author)
        if state_name is not None:
            patch.state = State.objects.get(name=state_name)
            patch.save()
        return patch

    def makeGerritChange(self, gerrit_id=None, patch=None, status='NEW',
                         change_id=None, last_updated_on=None):
        if gerrit_id is None:
            gerrit_id = self.getUniqueInteger()
        if patch is None:
            patch = self.makePatch()
        if change_id is None:
            change_id = self.getUniqueString()
        if last_updated_on is None:
            last_updated_on = datetime.now()
        change = GerritChange(
            gerrit_id=gerrit_id, patch=patch, status=status,
            change_id=change_id, last_updated_on=last_updated_on)
        change.save()
        return change


factory = PatchMetricsObjectFactory()
