from django.test import TestCase
from django.core.urlresolvers import reverse

from patchmetrics.tests.factory import factory


class PagesTest(TestCase):

    def test_frontpage(self):
        url = reverse('patchmetrics.views.frontpage')
        response = self.client.get(url)
        self.assertContains(response, 'Linaro patch metrics', status_code=200)

    def test_project_home(self):
        project = factory.makeProject()
        response = self.client.get(
            reverse('patchmetrics.views.project', args=[project.name]))
        self.assertContains(response, project.name, status_code=200,
                            msg_prefix=response.content)

    def test_team_home(self):
        team = factory.makeTeam()
        response = self.client.get(
            reverse('patchmetrics.views.team', args=[team.name]))
        self.assertContains(response, team.display_name, status_code=200,
                            msg_prefix=response.content)
        self.assertContains(response, '<table class="patchlist">')

    def test_faq(self):
        response = self.client.get(reverse('patchmetrics.views.faq'))
        self.assertContains(response, 'FAQ', status_code=200,
                            msg_prefix=response.content)

    def test_non_linaro_patches(self):
        response = self.client.get(
            reverse('patchmetrics.views.non_linaro_patches'))
        self.assertContains(
            response, 'Patches not coming from @linaro.org', status_code=200,
            msg_prefix=response.content)
        self.assertContains(response, '<table class="patchlist">')

    def test_patch_page(self):
        patch = factory.makePatch()
        url = reverse('patchmetrics.views.patch', args=[patch.id])
        response = self.client.get(url)
        self.assertContains(response, patch.name, status_code=200)
