# Django settings for patchwork project.
import os

DEBUG = False
TEMPLATE_DEBUG = DEBUG

ADMINS = (
     ('Jeremy Kerr', 'jk@ozlabs.org'),
)

MANAGERS = ADMINS

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.postgresql_psycopg2',
        'NAME': 'patchwork',
    },
}

# Local time zone for this installation. Choices can be found here:
# http://www.postgresql.org/docs/8.1/static/datetime-keywords.html#DATETIME-TIMEZONE-SET-TABLE
# although not all variations may be possible on all operating systems.
# If running in a Windows environment this must be set to the same as your
# system time zone.
TIME_ZONE = 'Australia/Canberra'

# Language code for this installation. All choices can be found here:
# http://www.w3.org/TR/REC-html40/struct/dirlang.html#langcodes
# http://blogs.law.harvard.edu/tech/stories/storyReader$15
LANGUAGE_CODE = 'en-au'

SITE_ID = 1

# If you set this to False, Django will make some optimizations so as not
# to load the internationalization machinery.
USE_I18N = True

# URL that handles the media served from MEDIA_ROOT.
# Example: "http://media.lawrence.com"
MEDIA_URL = ''

# URL prefix for admin media -- CSS, JavaScript and images. Make sure to use a
# trailing slash.
# Examples: "http://foo.com/media/", "/media/".
ADMIN_MEDIA_PREFIX = '/media/'

# Make this unique, and don't share it with anybody.
SECRET_KEY = '00000000000000000000000000000000000000000000000000'

# List of callables that know how to import templates from various sources.
TEMPLATE_LOADERS = (
    'django.template.loaders.filesystem.Loader',
    'django.template.loaders.app_directories.Loader',
#     'django.template.loaders.eggs.load_template_source',
)

MIDDLEWARE_CLASSES = (
    'django.middleware.common.CommonMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.middleware.doc.XViewMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
)

ROOT_URLCONF = 'apps.urls'

#LOGIN_URL = '/accounts/login'
LOGIN_URL = '/login'
LOGIN_REDIRECT_URL = '/user/'

# To make your Patchwork instance an OpenID relying party, you need to
# uncomment the lines below in your local_settings.py, and
#  - Add 'django_openid_auth' to INSTALLED_APPS;
#  - Add 'django_openid_auth.auth.OpenIDBackend' to AUTHENTICATION_BACKENDS;
#  - Uncomment the '^openid/' url pattern in apps/urls.py
# OPENID_CREATE_USERS = True
# OPENID_UPDATE_DETAILS_FROM_SREG = True
# LOGIN_URL = '/openid/login/'
# The line below is optional and will cause the given URL to be always used as
# the OpenID provider, so users won't have to enter their identity URL.
# OPENID_SSO_SERVER_URL = 'https://login.launchpad.net/'

AUTHENTICATION_BACKENDS = (
    'django.contrib.auth.backends.ModelBackend',
#    'django_openid_auth.auth.OpenIDBackend',
    'crowdrest.backend.CrowdRestBackend',
)

AUTH_CROWD_APPLICATION_USER = None
AUTH_CROWD_APPLICATION_PASSWORD = None
AUTH_CROWD_SERVER_REST_URI = 'https://login.linaro.org:8443/crowd/rest/usermanagement/1'

# If you change the ROOT_DIR setting in your local_settings.py, you'll need to
# re-define the variables that use this (MEDIA_ROOT and TEMPLATE_DIRS) too.
ROOT_DIR = '/srv/patchwork'
TEMPLATE_DIRS = (
    # Put strings here, like "/home/html/django_templates" or "C:/www/django/templates".
    # Always use forward slashes, even on Windows.
    # Don't forget to use absolute paths, not relative paths.
    os.path.join(ROOT_DIR, 'templates')
)
# Absolute path to the directory that holds media.
# Example: "/home/media/media.lawrence.com/"
MEDIA_ROOT = os.path.join(
    ROOT_DIR, 'lib', 'python', 'django', 'contrib', 'admin', 'media')

TEMPLATE_CONTEXT_PROCESSORS = (
    "django.core.context_processors.auth",
    "django.core.context_processors.debug",
    "django.core.context_processors.i18n",
    "django.core.context_processors.media",
    "patchwork.context_processors.login_url",
    "patchwork.context_processors.register_url",
)

AUTH_PROFILE_MODULE = "patchwork.userprofile"

INSTALLED_APPS = (
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.admin',
    #'django_openid_auth'
    'south',
    'longerusername',
    'crowdrest',
    'patchwork',
    'patchmetrics',
    'registration',
)

DEFAULT_PATCHES_PER_PAGE = 100
DEFAULT_FROM_EMAIL = 'Patchwork <patchwork@patchwork.example.com>'
# If set to True, this will cause the parsemail script to lookup projects
# by email address when one cannot be found by list ID.
PATCHWORK_FALLBACK_TO_LISTEMAIL = False
# The file containing the OAuth credentials for accessing Launchpad using
# launchpadlib.
LPLIB_CREDENTIALS_FILE = None
# The directory where launchpadlib stores its cache and other stuff. None
# means it will use the default, which is ~/.launchpadlib.
LPLIB_DIR = None

# The file containing Crowd credentials to access Linaro Login Crowd API.
CROWD_CREDENTIALS_FILE = None
# File with a list of groups that should be created in the DB. If other groups
# are taken out from Crowd, and they are not here, they will be skipped.
CROWD_GROUPS_WHITELIST = None

# Where to store the git repos that we scan to identify which patches have
# been committed.
PATCHWORK_GIT_REPOS_DIR = '/tmp'

ACCOUNT_ACTIVATION_DAYS = 7

# Set to True to enable the Patchwork XML-RPC interface
ENABLE_XMLRPC = False

# The project to use when we can't find a more appropriate one for a patch.
PATCHWORK_DEFAULT_PROJECT = 'other-unknown'

try:
    from local_settings import *
except ImportError, ex:
    import sys
    sys.stderr.write("settings.py: error importing local settings file:\n"
                     "\t%s\n"
                     "Do you have a local_settings.py module?\n" % str(ex))
    raise
